@@ -1,20 +1,38 @@
+/*
+ * (c) 1998-2018 by Columbia University; all rights reserved
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. Neither the name of the University nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 /*
  * rtp.h  --  RTP header file (RFC 1890)
  */
-#include "types.h"   /* changed from <sys/types.h> by Akira 12/27/01 */
 #include "sysdep.h"
 
-#if 0 /* types.h has a better definition for this. by Akira 12/27/01 */
-/*
- * The type definitions below are valid for 32-bit architectures and
- * may have to be adjusted for 16- or 64-bit architectures.
- */
-typedef unsigned char  u_int8;
-typedef unsigned short u_int16;
-typedef unsigned int   u_int32;
-typedef          short int16;
-#endif
-
 /*
  * System endianness -- determined by autoconf.
  */
@@ -74,16 +92,16 @@ typedef struct {
 #error Define one of RTP_LITTLE_ENDIAN or RTP_BIG_ENDIAN
 #endif
     unsigned int seq:16;      /* sequence number */
-    u_int32 ts;               /* timestamp */
-    u_int32 ssrc;             /* synchronization source */
-    u_int32 csrc[1];          /* optional CSRC list */
+    uint32_t ts;               /* timestamp */
+    uint32_t ssrc;             /* synchronization source */
+    uint32_t csrc[1];          /* optional CSRC list */
 } rtp_hdr_t;
 
-/* RTP Header Extension 
+/* RTP Header Extension
  */
 typedef struct {
-    u_int16 ext_type;         /* defined by profile */
-    u_int16 len;              /* extension length in 32-bit word */
+    uint16_t ext_type;         /* defined by profile */
+    uint16_t len;              /* extension length in 32-bit word */
 } rtp_hdr_ext_t;
 
 /*
@@ -116,21 +134,21 @@ typedef struct {
  * Reception report block
  */
 typedef struct {
-    u_int32 ssrc;             /* data source being reported */
+    uint32_t ssrc;             /* data source being reported */
     unsigned int fraction:8;  /* fraction lost since last SR/RR */
     int lost:24;              /* cumul. no. pkts lost (signed!) */
-    u_int32 last_seq;         /* extended last seq. no. received */
-    u_int32 jitter;           /* interarrival jitter */
-    u_int32 lsr;              /* last SR packet from this source */
-    u_int32 dlsr;             /* delay since last SR packet */
+    uint32_t last_seq;         /* extended last seq. no. received */
+    uint32_t jitter;           /* interarrival jitter */
+    uint32_t lsr;              /* last SR packet from this source */
+    uint32_t dlsr;             /* delay since last SR packet */
 } rtcp_rr_t;
 
 /*
  * SDES item
  */
 typedef struct {
-    u_int8 type;              /* type of item (rtcp_sdes_type_t) */
-    u_int8 length;            /* length of item (in octets) */
+    uint8_t type;             /* type of item (rtcp_sdes_type_t) */
+    uint8_t length;           /* length of item (in octets) */
     char data[1];             /* text, not null-terminated */
 } rtcp_sdes_item_t;
 
@@ -142,30 +160,30 @@ typedef struct {
     union {
         /* sender report (SR) */
         struct {
-            u_int32 ssrc;     /* sender generating this report */
-            u_int32 ntp_sec;  /* NTP timestamp */
-            u_int32 ntp_frac;
-            u_int32 rtp_ts;   /* RTP timestamp */
-            u_int32 psent;    /* packets sent */
-            u_int32 osent;    /* octets sent */ 
+            uint32_t ssrc;     /* sender generating this report */
+            uint32_t ntp_sec;  /* NTP timestamp */
+            uint32_t ntp_frac;
+            uint32_t rtp_ts;   /* RTP timestamp */
+            uint32_t psent;    /* packets sent */
+            uint32_t osent;    /* octets sent */
             rtcp_rr_t rr[1];  /* variable-length list */
         } sr;
 
         /* reception report (RR) */
         struct {
-            u_int32 ssrc;     /* receiver generating this report */
+            uint32_t ssrc;     /* receiver generating this report */
             rtcp_rr_t rr[1];  /* variable-length list */
         } rr;
 
         /* source description (SDES) */
         struct rtcp_sdes {
-            u_int32 src;      /* first SSRC/CSRC */
+            uint32_t src;      /* first SSRC/CSRC */
             rtcp_sdes_item_t item[1]; /* list of SDES items */
         } sdes;
 
         /* BYE */
         struct {
-            u_int32 src[1];   /* list of sources */
+            uint32_t src[1];   /* list of sources */
             /* can't express trailing text for reason */
         } bye;
     } r;
