@@ -1,32 +1,32 @@
 /*
-* RTP/RTCP packet dumper (RFC 1889)
-* Usage:
-*   rtpdump [address/port] > dump file
-*
-* Listens on port pair specified by argument for RTP and RTCP
-* packets, or reads from dump file.
-*
-*  -F format (names can be abbreviated):
-*     dump     dump in binary format (suitable for rtpplay)
-*     header   like 'dump', but don't save audio/video payload
-*     ascii    parsed packets (default)
-*     hex      like 'ascii', but with hex dump
-*     rtcp     like 'ascii', RTCP packets only
-*     short    RTP or vat data: [-]time ts [seq]
-*     payload  only audio/video payload
-*     
-*  -t d:    recording duration in minutes
-*  -x n:    number of payload bytes to dump per packet (hex, dump)
-*  -f name: name of input file, using "dump" format
-*  -o name: name of output file
-*
-* To record in chunks, simply build a shell script that loops,
-*  with suitably chosen file names. Each such file will be
-*  individually playable. (Gaps?)
-*
-* Copyright (c) 1995-2001 by H. Schulzrinne and Ping Pan (Columbia University)
-*   All Rights Reserved
-*/
+ * (c) 1998-2018 by Columbia University; all rights reserved
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. Neither the name of the University nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -39,7 +39,6 @@
 #include <errno.h>
 #include <unistd.h>      /* select(), perror() */
 #include <stdlib.h>      /* getopt(), atoi() */
-#include <math.h>        /* fmod() */
 #include <fcntl.h>       /* O_BINARY on Win32 */
 #include "rtp.h"
 #include "vat.h"
@@ -48,10 +47,9 @@
 #include "sysdep.h"
 #define RTPFILE_VERSION "1.0"
 
-typedef u_int32 member_t;
+typedef uint32_t member_t;
 
 static int verbose = 0; /* decode */
-static char rcsid[] = "$Id: rtpdump.c,v 1.6 2002/09/10 10:30:54 at541 Exp $";
 
 typedef enum {F_invalid, F_dump, F_header, F_hex, F_rtcp, F_short,
    F_payload, F_ascii} t_format;
@@ -67,10 +65,10 @@ static struct {
 
 static void usage(char *argv0)
 {
-  fprintf(stderr, 
-"Usage: %s [-F [hex|ascii|rtcp|short|payload|dump|header] [-t minutes]\
- [-o outputfile] [-f inputfile] [-x bytes] [multicast]/port > file\n", 
-  argv0);
+  fprintf(stderr, "usage: %s "
+	"[-F hex|ascii|rtcp|short|payload|dump|header] "
+	"[-f infile] [-o outfile] [-t minutes] [-x bytes] "
+	"[address]/port > file\n", argv0);
 }
 
 
@@ -233,6 +231,8 @@ static char *parse_type(int type, char *buf)
 static int parse_header(char *buf)
 {
   rtp_hdr_t *r = (rtp_hdr_t *)buf;
+  rtp_hdr_ext_t *ext;
+  int ext_len;
   int hlen = 0;
 
   if (r->version == 0) {
@@ -241,6 +241,13 @@ static int parse_header(char *buf)
   }
   else if (r->version == RTP_VERSION) {
     hlen = 12 + r->cc * 4;
+    
+    if (r->x) {  /* header extension */
+      ext = (rtp_hdr_ext_t *)((char *)buf + hlen);
+      ext_len = ntohs(ext->len);
+      
+      hlen += 4 + (ext_len * 4);
+    }
   }
 
   return hlen;
@@ -279,7 +286,7 @@ static int parse_data(FILE *out, char *buf, int len)
       (unsigned long)ntohl(r->ts),
       (unsigned long)ntohl(r->ssrc));
     for (i = 0; i < r->cc; i++) {
-      fprintf(out, "csrc[%d] = %0lx ", i, r->csrc[i]);
+      fprintf(out, "csrc[%d]=0x%0lx ", i, r->csrc[i]);
     }
     if (r->x) {  /* header extension */
       ext = (rtp_hdr_ext_t *)((char *)buf + hlen);
@@ -291,6 +298,7 @@ static int parse_data(FILE *out, char *buf, int len)
       if (ext_len) {
         fprintf(out, "ext_data=");
         hex(out, (char *)(ext+1), (ext_len*4));
+        fprintf(out, " ");
       }
     }
   }
@@ -365,7 +373,7 @@ void member_sdes(FILE *out, member_t m, rtcp_sdes_type_t t, char *b, int len)
 static char *rtp_read_sdes(FILE *out, char *b, int len)
 {
   rtcp_sdes_item_t *rsp;
-  u_int32 src = *(u_int32 *)b;
+  uint32_t src = *(uint32_t *)b;
   int total_len = 0;
 
   len -= 4;  /* subtract SSRC from available bytes */
@@ -503,7 +511,7 @@ static int parse_control(FILE *out, char *buf, int len)
           (unsigned long)ntohl(r->r.sdes.src));
       break;
       }
-      r = (rtcp_t *)((u_int32 *)r + ntohs(r->common.length) + 1);
+      r = (rtcp_t *)((uint32_t *)r + ntohs(r->common.length) + 1);
     }
   }
   else {
@@ -792,7 +800,7 @@ int main(int argc, char *argv[])
       }
       for (i = 0; i < 2; i++) {
         if (sock[i] >= 0 && FD_ISSET(sock[i], &readfds)) {
-          int alen = sizeof(sin);
+          socklen_t alen = sizeof(sin);
 
           /* subtract elapsed time from remaining timeout */
           gettimeofday(&now, 0);
