@@ -1,23 +1,34 @@
 /*
-* Recreate packet stream recorded with rtpdump -f dump.
-* Usage:
-* -v         verbose
-* -T         use absolute time rather than RTP timestamps
-* -f         file to read
-* -b         begin time
-* -e         end time
-* -s         local binding port
-* -p [file]  profile of RTP PT to frequency mappings
-* destination/port[/ttl]
-*
-* Program reads ahead by READAHEAD packets to compensate for reordering.
-* Currently does not correct SR/RR absolute (NTP) timestamps,
-* but should. Receiver reports are fairly meaningless.
-*
-* (c) 1994-1998 Henning Schulzrinne (Columbia University); all rights reserved
-*/
+ * (c) 1998-2018 by Columbia University; all rights reserved
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. Neither the name of the University nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
 
-#include <stdio.h>
+#include <stdint.h>
 #include <sys/types.h>
 #include <sys/time.h>    /* gettimeofday() */
 #include <sys/socket.h>  /* struct sockaddr */
@@ -37,18 +48,16 @@
 #endif
 #include "notify.h"      /* notify_start(), ... */
 #include "rtp.h"         /* RTP headers */
-#include "types.h"
 #include "rtpdump.h"     /* RD_packet_t */
 #include "multimer.h"    /* timer_set() */
 #include "ansi.h"
 
 #define READAHEAD 16 /* must be power of 2 */
 
-static char rcsid[] = "$Id: rtpplay.c,v 1.6 2002/09/10 10:24:10 at541 Exp $";
 static int verbose = 0;        /* be chatty about packets sent */
 static int wallclock = 0;      /* use wallclock time rather than timestamps */
-static u_int32 begin = 0;      /* time of first packet to send */
-static u_int32 end = UINT_MAX; /* when to stop sending */ 
+static uint32_t begin = 0;      /* time of first packet to send */
+static uint32_t end = UINT32_MAX; /* when to stop sending */ 
 static FILE *in;               /* input file */
 static int sock[2];            /* output sockets */
 static int first = -1;         /* time offset of first packet */
@@ -95,10 +104,9 @@ static double period[128] = {  /* ms per timestamp difference */
 
 static void usage(char *argv0)
 {
-  fprintf(stderr,
-"Usage: %s [-v] [-T] [-p profile] [-f file] [-b begin time] [-e end time] \
-[-s localport] destination/port[/ttl]\n",
-  argv0);
+  fprintf(stderr, "usage: %s "
+	"[-hTv] [-b begin] [-e end] [-f file] [-p profile] [-s port] "
+	"address/port[/ttl]\n", argv0);
   exit(1);
 } /* usage */
 
@@ -141,10 +149,10 @@ static Notify_value play_handler(Notify_client client)
   };
   struct rt_ts *t = 0;
   char ssrc[12];
-  u_int32 ts  = 0;
-  u_int8  pt  = 0;
-  u_int16 seq = 0;
-  u_int8  m   = 0;
+  uint32_t ts  = 0;
+  uint8_t  pt  = 0;
+  uint16_t seq = 0;
+  uint8_t  m   = 0;
   rtp_hdr_t *r;
   int b = (int)client;  /* buffer to be played now */
   int rp;        /* read pointer */
@@ -365,7 +373,7 @@ int main(int argc, char *argv[])
   }
 
   /* read header of input file */
-  if (RD_header(in, &sin, 0) < 0) {
+  if (RD_header(in, &sin, verbose) < 0) {
     fprintf(stderr, "Invalid header\n");
     exit(1);
   }
