@@ -1,48 +1,32 @@
 /*
-* RTP translator.
-*
-* Usage:
-*   rtptrans [host]/port[/ttl] [host]/port[/ttl] [...]
-*
-* Forwards RTP/RTCP packets from one of the named sockets to all
-* others.  Addresses can be a multicast or unicast.  TTL values for
-* unicast addresses are ignored. (Actually, doesn't check whether
-* packets are RTP or not.)
-*
-* It would be easy to add transcoding on a packet-by-packet basis (as
-*   long as the sampling rate doesn't change).
-*
-* Author: Henning Schulzrinne
-* Columbia University
-*
-*
-* Additionally, the translator can translate VAT packets into RTP packets. 
-* Thereby, the VAT control packets are translated into RTCP SDES packets with
-* a CNAME and a NAME entry. However, this is only entended to be used in the 
-* following configuration:
-* VAT packets arriving on a multicast connection are translated into RTP and
-* sent over a unicast link. RTP packets are not translated -not yet at least-
-* into VAT packets and and all packets arriving on unicast links are not
-* changed at all. Therefore, currently mainly the following topology is 
-* supported:
-*
-*    multicast VAT -> translator -> unicast RTP
-*
-*    and on the way back it should lokk like this
-*
-*    multicast VAT <- translator <- unicast VAT
-*
-*
-* This means that the audio agent on the unicast link should be able to use
-* both VAT and RTP.
-*
-* Author: Dorgham Sisalem
-* GMD Fokus, Berlin
-*
-* Bug fixes and supstantial improvements by 
-* Stephen Casner <casner@precept.com>
-* 
-*/
+ * (c) 1998-2018 by Columbia University; all rights reserved
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. Neither the name of the University nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
 
 #include <sys/types.h>
 #include <sys/uio.h>
@@ -122,11 +106,6 @@ int create_stream(int addr, int next)
     head=new_stream;
     middle=new_stream;
     list_len=1;
-#if !defined(nextstep)
-    srand48(rand());  /* initialize random number generator */
-#else
-    srand(rand());    /* (fred) This is surprising */
-#endif
     new_stream->seq=rand();
     last=new_stream;
     return new_stream->seq;
@@ -202,9 +181,10 @@ struct sdes_msg {
 */
 static Notify_value socket_handler(Notify_client client, int sock)
 {
-  int len, addr_len;
+  int len;
   int proto;
   struct sockaddr_in sin_from;
+  socklen_t addr_len;
   char packet[8192];
   int i;
   const int VAT_LEN=8;
@@ -326,7 +306,7 @@ static Notify_value socket_handler(Notify_client client, int sock)
         if (side[i][proto].sock != sock) {
           msg.msg_name = (caddr_t ) &side[i][proto].sin;
           msg.msg_namelen = sizeof(side[i][proto].sin);
-#if defined(__FreeBSD__) || defined(__linux__) || defined(__darwin__) /* Or presumably other BSD 4.4 systems */
+#if HAVE_MSGHDR_MSG_CONTROL
           msg.msg_control = 0;
           msg.msg_controllen = 0;
 #else
@@ -405,11 +385,8 @@ static Notify_value socket_handler(Notify_client client, int sock)
 
 void usage(char *argv0)
 {
-  fprintf(stderr, 
-"Usage: %s\
- host/port[/ttl]\
- host/port[/ttl] [...]\n",
- argv0);
+  fprintf(stderr, "usage: %s address/port[/ttl] address/port[/ttl] [...]\n",
+	argv0);
 }
 
 int main(int argc, char *argv[])
@@ -445,7 +422,6 @@ int main(int argc, char *argv[])
   }
 
   if (argc - optind < 2) {
-    fprintf(stderr, "%s: Requires two host/port[/tll].\n", argv[0]);
     usage(argv[0]);
     exit(1);
   }
